sdk_path = "/home/vagrant/android-sdk"
ndk_paths = {
    'r9b': "/home/vagrant/android-ndk/r9b",
    'r10e': "/home/vagrant/android-ndk/r10e",
    'r11c': "/home/vagrant/android-ndk/r11c",
    'r12b': "/home/vagrant/android-ndk/r12b",
}
java_paths = {
    '8': "/usr/lib/jvm/java-8-openjdk-i386",
}
